@@ -1,5 +1,5 @@
 package Test::WWW::Mechanize::Mojo;
-$Test::WWW::Mechanize::Mojo::VERSION = '0.0.19';
+$Test::WWW::Mechanize::Mojo::VERSION = '0.0.20';
 use strict;
 use warnings;
 
@@ -153,7 +153,7 @@ sub _make_request
         while ( $end_of_chain->previous )    # keep going till the end
         {
             $end_of_chain = $end_of_chain->previous;
-        }                                          #   of the chain...
+        }                                    #   of the chain...
         $end_of_chain->previous($old_response);    # ...and add us to it
     }
     else
@@ -300,7 +300,7 @@ Test::WWW::Mechanize::Mojo - Test::WWW::Mechanize for Mojo / Mojolicious
 
 =head1 VERSION
 
-version 0.0.19
+version 0.0.20
 
 =head1 SYNOPSIS
 
@@ -387,10 +387,6 @@ please use:
 
 An alternative to this module is L<Test::Mojo>.
 
-=head1 VERSION
-
-version 0.0.19
-
 =head1 CONSTRUCTOR
 
 =head2 new
@@ -642,7 +638,7 @@ the same terms as the Perl 5 programming language system itself.
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-L<https://github.com/shlomif/test-www-mechanize-mojo/issues>
+L<https://github.com/shlomif/perl-test-www-mechanize-mojo/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -751,8 +747,8 @@ The code is open to the world, and available for you to hack on. Please feel fre
 with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
 from your repository :)
 
-L<https://github.com/shlomif/test-www-mechanize-mojo>
+L<https://github.com/shlomif/perl-test-www-mechanize-mojo>
 
-  git clone git://github.com/shlomif/test-www-mechanize-mojo.git
+  git clone git://github.com/shlomif/perl-test-www-mechanize-mojo.git
 
 =cut
